/*
 * setchar for virtual font
 */

#include	"defs.h"
#include	"commands.h"
#include	"dconv.h"
#include	"global.h"
#include	"set.h"

void
virf_setchar(c, Move)
int c;
BOOLEAN Move;
{
    int cw;

    chmove = Move;
    cw = DEV_setchar(c);
    if (Move)
	*move += cw;

#ifdef STATS
    Stnc += 1;
    curfontent->ncts += 1;
#endif
}

#define	STRLEN		256
void
virf_setstring(firstch)	/* read and set a consecutive string of chars */
int firstch;
{
    char s[STRLEN];
    char *sp;
    int c, len, w;

    /* read entire string of chars */
    /* ensure that all characters are loaded, */
    for (c = firstch, sp = s, len = 0;
	 c >= SETC_000 && c <= SETC_127 && len < STRLEN; len++) {
	*sp++ = c;
	c = DC_getcommand();
    }
    DC_backupone();

    chmove = TRUE;
    w = DEV_setstring(s, len);
    *move += w;

#ifdef STATS
    Stnc += len;
    curfontent->ncts += len;
#endif
}
